summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/oplog_batcher.h
diff options
context:
space:
mode:
authorali-mir <ali.mir@mongodb.com>2021-10-08 15:15:55 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2021-10-08 16:36:10 +0000
commit05ce07113980c285bf6d8cbb707e4fb96f160239 (patch)
tree27f390ed863f9dadfa517b1aee3360e4e1978802 /src/mongo/db/repl/oplog_batcher.h
parent292a5a011cf8d1aa32a8f33e44ea21f2b4609d84 (diff)
downloadmongo-05ce07113980c285bf6d8cbb707e4fb96f160239.tar.gz
SERVER-60544 Replace remaining references to slaveDelay in replication system
Diffstat (limited to 'src/mongo/db/repl/oplog_batcher.h')
-rw-r--r--src/mongo/db/repl/oplog_batcher.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/repl/oplog_batcher.h b/src/mongo/db/repl/oplog_batcher.h
index 1449af45ed8..21ce5010d80 100644
--- a/src/mongo/db/repl/oplog_batcher.h
+++ b/src/mongo/db/repl/oplog_batcher.h
@@ -130,9 +130,9 @@ public:
size_t ops = 0;
// If provided, the batch will not include any operations with timestamps after this point.
- // This is intended for implementing slaveDelay, so it should be some number of seconds
- // before now.
- boost::optional<Date_t> slaveDelayLatestTimestamp = {};
+ // This is intended for implementing secondaryDelaySecs, so it should be some number of
+ // seconds before now.
+ boost::optional<Date_t> secondaryDelaySecsLatestTimestamp = {};
// If non-null, the batch will include operations with timestamps either
// before-and-including this point or after it, not both.
@@ -167,7 +167,7 @@ public:
* A batch may consist of:
* at most "BatchLimits::ops" OplogEntries
* at most "BatchLimits::bytes" worth of OplogEntries
* only OplogEntries from before the "BatchLimits::slaveDelayLatestTimestamp" point
* a single command OplogEntry (excluding applyOps, which are grouped with CRUD ops)
*/
StatusWith<std::vector<OplogEntry>> getNextApplierBatch(OperationContext* opCtx,
@@ -187,10 +187,10 @@ public:
private:
/**
* If slaveDelay is enabled, this function calculates the most recent timestamp of any oplog
* entries that can be be returned in a batch.
*/
- boost::optional<Date_t> _calculateSlaveDelayLatestTimestamp();
+ boost::optional<Date_t> _calculateSecondaryDelaySecsLatestTimestamp();
/**
* Pops the operation at the front of the OplogBuffer.
@@ -167,7 +167,7 @@ public:
* at most "BatchLimits::ops" OplogEntries
* at most "BatchLimits::bytes" worth of OplogEntries
- * only OplogEntries from before the "BatchLimits::slaveDelayLatestTimestamp" point
+ * only OplogEntries from before the "BatchLimits::secondaryDelaySecsLatestTimestamp" point
* a single command OplogEntry (excluding applyOps, which are grouped with CRUD ops)
*/
@@ -187,10 +187,10 @@ public:
private:
/**
- * If slaveDelay is enabled, this function calculates the most recent timestamp of any oplog
- * entries that can be be returned in a batch.
+ * If secondaryDelaySecs is enabled, this function calculates the most recent timestamp of any
+ * oplog entries that can be be returned in a batch.
*/